@@ -183,6 +183,54 @@ void PhoneNumberTest::labelTest()
              QLatin1String("Work Fax/Preferred"));
 }
 
+void PhoneNumberTest::shouldParseVCard21()
+{
+    QByteArray vcarddata("BEGIN:VCARD\n"
+                        "VERSION:2.1\n"
+                        "EMAIL:foo@kde.org\n"
+                        "N:;;;;\n"
+                        "TEL;CELL;WORK:+1-919-676-9564\n"
+                        "UID:testuid\n"
+                        "END:VCARD\n"
+                        "\n");
+
+    KContacts::VCardTool vcard;
+    const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
+    QCOMPARE(lst.count(), 1);
+    KContacts::Addressee addr = lst.at(0);
+    QCOMPARE(addr.phoneNumbers().count(), 1);
+    KContacts::PhoneNumber number1 = addr.phoneNumbers().at(0);
+    //QCOMPARE(number1.number(), QString());
+}
+
+void PhoneNumberTest::shouldExportVCard21()
+{
+    KContacts::AddresseeList lst;
+    KContacts::Addressee addr;
+    addr.setEmails(QStringList() << QStringLiteral("foo@kde.org"));
+    addr.setUid(QStringLiteral("testuid"));
+
+    KContacts::PhoneNumber number1;
+
+    number1.setId(QStringLiteral("My Id"));
+    number1.setType(KContacts::PhoneNumber::Work | KContacts::PhoneNumber::Cell);
+    number1.setNumber(QStringLiteral("+1-919-676-9564"));
+    addr.setPhoneNumbers(KContacts::PhoneNumber::List() << number1);
+    lst << addr;
+    KContacts::VCardTool vcard;
+    const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v2_1);
+    QByteArray expected("BEGIN:VCARD\r\n"
+                        "VERSION:2.1\r\n"
+                        "EMAIL:foo@kde.org\r\n"
+                        "N:;;;;\r\n"
+                        "TEL;CELL;WORK:+1-919-676-9564\r\n"
+                        "UID:testuid\r\n"
+                        "END:VCARD\r\n"
+                        "\r\n");
+    QCOMPARE(ba, expected);
+
+}
+
 void PhoneNumberTest::shouldExportVCard3()
 {
     KContacts::AddresseeList lst;
@@ -247,7 +295,7 @@ void PhoneNumberTest::shouldParseVcard3()
                          "TEL;VALUE=uri;TYPE=\"voice,cell,text\":tel:+44-555-555-6666\r\n"
                          "TEL;VALUE=uri;TYPE=\"voice,work\":tel:+44-555-555-7777\r\n"
                          "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
-                         "LANG:fr"
+                         "LANG:fr\n"
                          "REV:2015-03-14T09:24:45+00:00\n"
                          "FN:FirstName LastName\n"
                          "END:VCARD\n");
@@ -268,7 +316,7 @@ void PhoneNumberTest::shouldParseVcard4()
                          "TEL;VALUE=uri;TYPE=\"voice,cell,text\":tel:+44-555-555-6666\r\n"
                          "TEL;VALUE=uri;TYPE=\"voice,work\":tel:+44-555-555-7777\r\n"
                          "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
-                         "LANG:fr"
+                         "LANG:fr\n"
                          "REV:2015-03-14T09:24:45+00:00\n"
                          "FN:FirstName LastName\n"
                          "END:VCARD\n");
