@@ -49,6 +49,7 @@ public:
         : mUid(QUuid::createUuid().toString().mid(1, 36))
         , mEmpty(true)
         , mChanged(false)
+        , mBirthdayWithTime(false)
     {
         //We avoid the curly braces so the string is RFC4122 compliant and can be used as urn
     }
@@ -65,6 +66,7 @@ public:
         mPrefix = other.mPrefix;
         mSuffix = other.mSuffix;
         mBirthday = other.mBirthday;
+        mBirthdayWithTime = other.mBirthdayWithTime;
         mMailer = other.mMailer;
         mTimeZone = other.mTimeZone;
         mGeo = other.mGeo;
@@ -151,8 +153,10 @@ public:
     Role::List mRoleExtraList;
     Org::List mOrgExtraList;
     NickName::List mNickNameExtraList;
+    ClientPidMap::List mClientPidMapList;
     bool mEmpty    : 1;
     bool mChanged  : 1;
+    bool mBirthdayWithTime;
 
     static KContacts::SortMode *mSortMode;
 };
@@ -231,7 +235,7 @@ bool Addressee::operator==(const Addressee &addressee) const
         return false;
     }
 
-    if (d->mBirthday != addressee.d->mBirthday) {
+    if (d->mBirthday != addressee.d->mBirthday || d->mBirthdayWithTime != addressee.d->mBirthdayWithTime) {
         qCDebug(KCONTACTS_LOG) << "birthday differs";
         return false;
     }
@@ -397,6 +401,11 @@ bool Addressee::operator==(const Addressee &addressee) const
         qCDebug(KCONTACTS_LOG) << "Extra NickName List differs";
         return false;
     }
+
+    if (!listEquals(d->mClientPidMapList, addressee.d->mClientPidMapList)) {
+        qCDebug(KCONTACTS_LOG) << "ClientPidMap List differs";
+        return false;
+    }
     return true;
 }
 
@@ -572,6 +581,26 @@ void Addressee::insertFieldGroup(const FieldGroup &fieldGroup)
     }
 }
 
+ClientPidMap::List Addressee::clientPidMapList() const
+{
+    return d->mClientPidMapList;
+}
+
+void Addressee::setClientPidMapList(const ClientPidMap::List &clientpidmaplist)
+{
+    d->mEmpty = false;
+    d->mClientPidMapList = clientpidmaplist;
+}
+
+void Addressee::insertClientPidMap(const ClientPidMap &clientpidmap)
+{
+    if (clientpidmap.isValid()) {
+        d->mEmpty = false;
+        //TODO don't duplicate ?
+        d->mClientPidMapList.append(clientpidmap);
+    }
+}
+
 void Addressee::insertImpp(const Impp &impp)
 {
     if (impp.isValid()) {
@@ -777,14 +806,29 @@ QString Addressee::nickNameLabel()
     return i18n("Nick Name");
 }
 
-void Addressee::setBirthday(const QDateTime &birthday)
+void Addressee::setBirthday(const QDateTime &birthday, bool withTime)
 {
-    if (birthday == d->mBirthday) {
+    if (birthday == d->mBirthday && d->mBirthdayWithTime == withTime) {
         return;
     }
 
     d->mEmpty = false;
     d->mBirthday = birthday;
+    if (!withTime) {
+        d->mBirthday.setTime(QTime());
+    }
+    d->mBirthdayWithTime = withTime;
+}
+
+void Addressee::setBirthday(const QDate &birthday)
+{
+    if (birthday == d->mBirthday.date() && !d->mBirthdayWithTime) {
+        return;
+    }
+
+    d->mEmpty = false;
+    d->mBirthday = QDateTime(birthday, QTime());
+    d->mBirthdayWithTime = false;
 }
 
 QDateTime Addressee::birthday() const
@@ -792,6 +836,11 @@ QDateTime Addressee::birthday() const
     return d->mBirthday;
 }
 
+bool Addressee::birthdayHasTime() const
+{
+    return d->mBirthdayWithTime;
+}
+
 QString Addressee::birthdayLabel()
 {
     return i18n("Birthday");
@@ -2389,6 +2438,7 @@ QDataStream &KContacts::operator<<(QDataStream &s, const Addressee &a)
     s << a.d->mPrefix;
     s << a.d->mSuffix;
     s << a.d->mBirthday;
+    s << a.d->mBirthdayWithTime;
     s << a.d->mMailer;
     s << a.d->mTimeZone;
     s << a.d->mGeo;
@@ -2424,6 +2474,7 @@ QDataStream &KContacts::operator<<(QDataStream &s, const Addressee &a)
     s << a.d->mRoleExtraList;
     s << a.d->mOrgExtraList;
     s << a.d->mNickNameExtraList;
+    s << a.d->mClientPidMapList;
 
     return s;
 }
@@ -2440,6 +2491,7 @@ QDataStream &KContacts::operator>>(QDataStream &s, Addressee &a)
     s >> a.d->mPrefix;
     s >> a.d->mSuffix;
     s >> a.d->mBirthday;
+    s >> a.d->mBirthdayWithTime;
     s >> a.d->mMailer;
     s >> a.d->mTimeZone;
     s >> a.d->mGeo;
@@ -2477,6 +2529,7 @@ QDataStream &KContacts::operator>>(QDataStream &s, Addressee &a)
     s >> a.d->mRoleExtraList;
     s >> a.d->mOrgExtraList;
     s >> a.d->mNickNameExtraList;
+    s >> a.d->mClientPidMapList;
     a.d->mEmpty = false;
 
     return s;
