@@ -1,15 +1,27 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2016-2019 Laurent Montel <montel@kde.org>
+    Copyright (c) 2016 Laurent Montel <montel@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "clientpidmap.h"
-#include "parametermap_p.h"
-
+#include <QMap>
+#include <qstringlist.h>
 #include <QDataStream>
-#include <QStringList>
 
 using namespace KContacts;
 
@@ -23,22 +35,23 @@ public:
     Private(const Private &other)
         : QSharedData(other)
     {
-        mParamMap = other.mParamMap;
+        parameters = other.parameters;
         clientpidmap = other.clientpidmap;
     }
-
-    ParameterMap mParamMap;
+    QMap<QString, QStringList> parameters;
     QString clientpidmap;
 };
 
 ClientPidMap::ClientPidMap()
     : d(new Private)
 {
+
 }
 
 ClientPidMap::ClientPidMap(const ClientPidMap &other)
     : d(other.d)
 {
+
 }
 
 ClientPidMap::ClientPidMap(const QString &clientpidmap)
@@ -49,6 +62,7 @@ ClientPidMap::ClientPidMap(const QString &clientpidmap)
 
 ClientPidMap::~ClientPidMap()
 {
+
 }
 
 void ClientPidMap::setClientPidMap(const QString &clientpidmap)
@@ -66,33 +80,19 @@ bool ClientPidMap::isValid() const
     return !d->clientpidmap.isEmpty();
 }
 
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
 void ClientPidMap::setParameters(const QMap<QString, QStringList> &params)
 {
-    d->mParamMap = ParameterMap::fromQMap(params);
+    d->parameters = params;
 }
-#endif
 
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
 QMap<QString, QStringList> ClientPidMap::parameters() const
 {
-    return d->mParamMap.toQMap();
-}
-#endif
-
-void ClientPidMap::setParams(const ParameterMap &params)
-{
-    d->mParamMap = params;
-}
-
-ParameterMap ClientPidMap::params() const
-{
-    return d->mParamMap;
+    return d->parameters;
 }
 
 bool ClientPidMap::operator==(const ClientPidMap &other) const
 {
-    return (d->mParamMap == other.d->mParamMap) && (d->clientpidmap == other.clientPidMap());
+    return (d->parameters == other.parameters()) && (d->clientpidmap == other.clientPidMap());
 }
 
 bool ClientPidMap::operator!=(const ClientPidMap &other) const
@@ -111,20 +111,29 @@ ClientPidMap &ClientPidMap::operator=(const ClientPidMap &other)
 
 QString ClientPidMap::toString() const
 {
-    QString str = QLatin1String("ClientPidMap {\n");
+    QString str;
+    str += QLatin1String("ClientPidMap {\n");
     str += QStringLiteral("    clientpidmap: %1\n").arg(d->clientpidmap);
-    str += d->mParamMap.toString();
+    if (!d->parameters.isEmpty()) {
+        QMapIterator<QString, QStringList> i(d->parameters);
+        QString param;
+        while (i.hasNext()) {
+            i.next();
+            param += QStringLiteral("%1 %2").arg(i.key(), i.value().join(QLatin1Char(',')));
+        }
+        str += QStringLiteral("    parameters: %1\n").arg(param);
+    }
     str += QLatin1String("}\n");
     return str;
 }
 
 QDataStream &KContacts::operator<<(QDataStream &s, const ClientPidMap &clientpidmap)
 {
-    return s << clientpidmap.d->mParamMap << clientpidmap.d->clientpidmap;
+    return s << clientpidmap.d->parameters << clientpidmap.d->clientpidmap;
 }
 
 QDataStream &KContacts::operator>>(QDataStream &s, ClientPidMap &clientpidmap)
 {
-    s >> clientpidmap.d->mParamMap >> clientpidmap.d->clientpidmap;
+    s >> clientpidmap.d->parameters >> clientpidmap.d->clientpidmap;
     return s;
 }
