@@ -1,6 +1,6 @@
 /*
     This file is part of libkabc.
-    Copyright (c) 2015 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015-2016 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -133,7 +133,7 @@ QString Impp::toString() const
         QString param;
         while (i.hasNext()) {
             i.next();
-            param += QStringLiteral("%1 %2").arg(i.key(), i.value().join(QStringLiteral(",")));
+            param += QStringLiteral("%1 %2").arg(i.key(), i.value().join(QLatin1Char(',')));
         }
         str += QStringLiteral("    parameters: %1\n").arg(param);
     }
